[MOBY-guts] biomoby commit

Eddie Kawas kawas at dev.open-bio.org
Wed Mar 5 17:52:46 UTC 2008


kawas
Wed Mar  5 12:52:46 EST 2008
Update of /home/repository/moby/moby-live/Perl/MOBY-Client
In directory dev.open-bio.org:/tmp/cvs-serv16872/Perl/MOBY-Client

Modified Files:
	populate_libs.pl 
Log Message:
added the new modules 'NamespaceParser, ServiceTypeParser, Utils'
moby-live/Perl/MOBY-Client populate_libs.pl,1.1,1.2
===================================================================
RCS file: /home/repository/moby/moby-live/Perl/MOBY-Client/populate_libs.pl,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- /home/repository/moby/moby-live/Perl/MOBY-Client/populate_libs.pl	2008/02/21 00:14:33	1.1
+++ /home/repository/moby/moby-live/Perl/MOBY-Client/populate_libs.pl	2008/03/05 17:52:46	1.2
@@ -12,6 +12,8 @@
 my @Async 		= qw ( LSAE.pm Service.pm SimpleServer.pm WSRF.pm );
 my @Client		= qw ( Central.pm CollectionArticle.pm OntologyServer.pm Registration.pm SecondaryArticle.pm Service.pm ServiceInstance.pm SimpleArticle.pm SimpleInput.pm );
 my @Exception 	= qw ( MobyException.pm MobyExceptionCodes.pm );
+my @RDF 		= qw ( Utils.pm );
+my @Parsers 	= qw ( ServiceTypeParser.pm NamespaceParser.pm );
 
 # current working directory ...
 my $dir = getcwd;
@@ -55,6 +57,18 @@
 	warn "couldn't copy file $file: $!\n" unless copy("$origin_directory/$subpath/$file","$destination_directory/$subpath/$file") == 1;
 }
 
+# copy the RDF files
+foreach my $file (@RDF) {
+	my $subpath = "MOBY/RDF";
+	warn "couldn't copy file $file: $!\n" unless copy("$origin_directory/$subpath/$file","$destination_directory/$subpath/$file") == 1;
+}
+
+# copy the Parsers files
+foreach my $file (@Parsers) {
+	my $subpath = "MOBY/RDF/Parsers";
+	warn "couldn't copy file $file: $!\n" unless copy("$origin_directory/$subpath/$file","$destination_directory/$subpath/$file") == 1;
+}
+
 
 # Directory Structure is:
 #
@@ -71,16 +85,23 @@
 #    ¦       WSRF.pm
 #    ¦
 #    +---Client
 #        ¦   Central.pm
 #        ¦   CollectionArticle.pm
 #        ¦   OntologyServer.pm
 #        ¦   Registration.pm
 #        ¦   SecondaryArticle.pm
 #        ¦   Service.pm
 #        ¦   ServiceInstance.pm
 #        ¦   SimpleArticle.pm
 #        ¦   SimpleInput.pm
 #        ¦
 #        +---Exception
 #                MobyException.pm
 #                MobyExceptionCodes.pm
@@ -71,16 +85,23 @@
 #    ¦
 #    +---Client
-#        ¦   Central.pm
-#        ¦   CollectionArticle.pm
-#        ¦   OntologyServer.pm
-#        ¦   Registration.pm
-#        ¦   SecondaryArticle.pm
-#        ¦   Service.pm
-#        ¦   ServiceInstance.pm
-#        ¦   SimpleArticle.pm
-#        ¦   SimpleInput.pm
-#        ¦
-#        +---Exception
-#                MobyException.pm
-#                MobyExceptionCodes.pm
+#    ¦   ¦   Central.pm
+#    ¦   ¦   CollectionArticle.pm
+#    ¦   ¦   OntologyServer.pm
+#    ¦   ¦   Registration.pm
+#    ¦   ¦   SecondaryArticle.pm
+#    ¦   ¦   Service.pm
+#    ¦   ¦   ServiceInstance.pm
+#    ¦   ¦   SimpleArticle.pm
+#    ¦   ¦   SimpleInput.pm
+#    ¦   ¦
+#    ¦   +---Exception
+#    ¦           MobyException.pm
+#    ¦           MobyExceptionCodes.pm
+#    ¦
+#    +---RDF
+#    ¦   ¦   Utils.pm
+#    ¦   ¦   
+#    ¦   +---Parsers
+#    ¦           ServiceTypeParser.pm
+#    ¦           NamespaceParser.pm






More information about the MOBY-guts mailing list